@@ -61,16 +61,16 @@ print(data.frame(row.names = nameTrt, sum=means[,2]))
 cat("\nDurbin Test")
 cat("\n===========")
 cat("\nValue      :",s)
-cat("\nDf 1       :",gl1)
+cat("\nDF 1       :",gl1)
 cat("\nP-value    :",prob)
 cat("\nAlpha      :",alpha)
-cat("\nDf 2       :",gl2)
+cat("\nDF 2       :",gl2)
 cat("\nt-Student  :",Tprob)
 cat("\n\nLeast Significant Difference\nbetween the sum of ranks: ",LSD,"\n")
 # comparacion de tratamientos.
 cat("\nParameters BIB")
 cat("\nLambda     :",lambda)
-cat("\ntreatmeans :",ntr)
+cat("\nTreatmeans :",ntr)
 cat("\nBlock size :",k)
 cat("\nBlocks     :",b)
 cat("\nReplication:",r,"\n")
