@@ -1,8 +1,7 @@
-`lastC` <-
+lastC <-
 function(x) {
 y<-sub(" +$", "",x)
 p1<-nchar(y)
 cc<-substr(y,p1,p1)
 return(cc)
 }
-
